@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 """nginxstats - Munin Plugin to monitor stats for Nginx Web Server.
 
 Requirements
@@ -40,8 +40,8 @@ Environment Variables
 
 """
 # Munin  - Magic Markers
-#%# family=manual
-#%# capabilities=noautoconf nosuggest
+#%# family=auto
+#%# capabilities=autoconf nosuggest
 
 import sys
 from pymunin import MuninGraph, MuninPlugin, muninMain
@@ -79,12 +79,12 @@ class MuninNginxPlugin(MuninPlugin):
         MuninPlugin.__init__(self, argv, env, debug)
         
         self._host = self.envGet('host')
-        self._port = self.envGet('port')
+        self._port = self.envGet('port', None, int)
         self._user = self.envGet('user')
         self._password = self.envGet('password')
         self._statuspath = self.envGet('statuspath')
         self._ssl = self.envCheckFlag('ssl', False)
-        self._numSamples = self.envGet('samples', defaultNumSamples)  
+        self._numSamples = self.envGet('samples', defaultNumSamples, int)  
         
         if self.graphEnabled('nginx_activeconn'):
             graph = MuninGraph('Nginx - Active Connections', 
@@ -169,7 +169,18 @@ class MuninNginxPlugin(MuninPlugin):
                     self.setGraphVal('nginx_requestsperconn', 'requests', 0)
                 hist_stats.append(curr_stats)
                 self.saveState(hist_stats[-self._numSamples:])
-                
+    
+    def autoconf(self):
+        """Implements Munin Plugin Auto-Configuration Option.
+        
+        @return: True if plugin can be  auto-configured, False otherwise.
+                 
+        """
+        nginxInfo = NginxInfo(self._host, self._port,
+                                self._user, self._password, 
+                                self._statuspath, self._ssl)
+        return nginxInfo is not None
+    
 
 def main():
     sys.exit(muninMain(MuninNginxPlugin))
